@@ -48,19 +48,20 @@ Internal methods are usually preceded with a _
 
 # Let the code begin...
 
-
 package Bio::Graphics::Browser2::Plugin::SequenceDumper;
 # $Id: SequenceDumper.pm,v 1.18 2009-01-02 20:57:37 lstein Exp $
 # Sequence Dumper plugin
 
 use strict;
 use Bio::Graphics::Browser2::Plugin;
+use Bio::SeqFeature::Generic;
 use Bio::SeqIO;
 use Bio::Seq::RichSeq;
-use POSIX qw(strftime);
-use Bio::Location::Fuzzy;
+use Bio::Graphics::Browser2::TrackDumper::RichSeqMaker;
+
 use CGI qw(:standard *pre);
-use Bio::SeqFeature::Generic;
+use POSIX qw(strftime);
+
 use vars qw($VERSION @ISA);
 use constant DEBUG => 0;
 
@@ -70,7 +71,6 @@ my @FORMATS = ( 'fasta'   => ['Fasta',        undef],
 		'embl'    => ['EMBL',         undef],
 		'gcg'     => ['GCG',          undef],
 		'raw'     => ['Raw sequence', undef],
-		'game'    => ['GAME (XML)',   'xml'],
 		'bsml'    => ['BSML (XML)',   'xml'],
 		'gff'     => ['GFF3',          undef],
 	      );
@@ -118,68 +118,8 @@ sub dump {
     return;
   }
   my @filter    = $self->selected_features;
-  my $seq  = new Bio::Seq::RichSeq(-display_id       => $segment->display_id,
-				   -desc             => $segment->desc,
-				   -accession_number => $segment->accession_number,
-				   
-				   -alphabet         => $segment->alphabet || 'dna',
-			  );
-  $seq->add_date(strftime("%d-%b-%Y",localtime));
-  my $ps = $segment->primary_seq; 
-  $seq->primary_seq(!ref $ps ? Bio::PrimarySeq->new(-seq=>$ps) : $ps);
-  $segment->absolute(1);
-  my $offset     = $segment->start - 1;
-  my $segmentend = $segment->length;
-  $seq->add_SeqFeature( map {
-      my $score = $_->score;
-      $score    = ref $score eq 'HASH' ? $score->{sumData}/$score->{validCount} : $score;
-      my $nf = new Bio::SeqFeature::Generic(-primary_tag => $_->primary_tag,
-					    -source_tag  => $_->source_tag,
-					    -frame       => eval{$_->phase}||eval{$_->frame}||undef,
-					    -score       => $score,
-					    );
-      for my $tag ( $_->get_all_tags ) {
-	  my %seen;
-	  $nf->add_tag_value($tag, grep { ! $seen{$_}++ } 
-			     grep { defined } $_->get_tag_values($tag));
-      }
-      my $loc = $_->location;
-      my @locs = $loc->each_Location;
-      for my $sl (@locs ) {
-	  $sl->start($sl->start() - $offset);
-	  $sl->end  ($sl->end() - $offset );
-	  my ($startstr,$endstr);
-
-	  if( $sl->start() < 1) {
-	      $startstr = "<1";
-	      $endstr   = $sl->end;
-	  }
-	  
-	  if( $sl->end() > $segmentend) {
-	      $endstr = ">$segmentend";
-	      $startstr = $sl->start unless defined $startstr;
-	  }
-	  if( defined $startstr || defined $endstr ) {
-	      $sl = Bio::Location::Fuzzy->new(-start         => $startstr,
-					      -end           => $endstr,
-					      -strand        => $sl->strand,
-					      -location_type => '..');
-	      # warn $sl->to_FTstring();
-	  }
-      }
-      if( @locs > 1 ) { 
-	  # let's insure they are sorted
-          if( $wantsorted ) {  # for VectorNTI
-	      @locs = sort { $a->start <=> $b->start } @locs;
-          }
-	  $nf->location( new Bio::Location::Split(-locations => \@locs,
-						  -seq_id    =>
-						  $segment->display_id));
-      } else { 
-	  $nf->location(shift @locs);
-      }
-      $nf;
-  } $segment->features(-types => \@filter) );
+  my $iterator  = $segment->get_seq_stream(-types => \@filter);
+  my $seq =  Bio::Graphics::Browser2::TrackDumper::RichSeqMaker->stream_to_rich_seq($segment,$iterator);
 
   my $out = new Bio::SeqIO(-format => $config->{fileformat},-fh=>\*STDOUT);
   my $mime_type = $self->mime_type;
