@@ -408,7 +408,7 @@ sub label2type {
 
 sub track_listing_class {
     my $self = shift;
-    my $style    =  lc $self->global_setting('track listing style') || 'categories';
+    my $style    =  lc($self->global_setting('track listing style') || 'categories');
     my $subclass =   $style eq 'categories' ? 'Categories'
 	           : $style eq 'facets'     ? 'Facets'
 		   : die "invalid track listing style '$style'";
@@ -1358,6 +1358,10 @@ sub use_inline_imagemap {
     my $inline = $self->semantic_fallback_setting($label=>'inline imagemaps',$length) 
 	       ||$self->semantic_fallback_setting($label=>'inline imagemap', $length);
     return $inline if defined $inline;
+    return 1 if not (Bio::Graphics::Browser2::Render->fcgi_request()
+		     ||
+		     $ENV{MOD_PERL_API_VERSION}
+	);
     my $db = $self->open_database($label,$length) or return 1;
     return !$db->can('get_feature_by_id');
 }
